==> activity-center-api-1.0.2-20160620.021236-21-sources.jar: cn/com/duiba/activity/center/api/dto/singlelottery/SingleLotteryAppSpecifyDto.java <==
package cn.com.duiba.activity.center.api.dto.singlelottery;

import java.util.Date;

/**
 * Created by yansen on 16/6/17.
 */
public class SingleLotteryAppSpecifyDto {
    private static final long serialVersionUID = 380776798442497916L;
    private Long id;

    private Long duibaSingleLotteryId; // 兑吧单品抽奖ID

    private Long appId; // appId

    private Integer orderCount; // 已兑数量

    private Integer remaining; // 剩余限额

    private Date gmtCreate;

    private Date gmtModified;

    @Override
    public String toString() {
        return "SingleLotteryAppSpecifyDO [id=" + id + "]";
    }

    public SingleLotteryAppSpecifyDto() {
    }

    public SingleLotteryAppSpecifyDto(Long id) {
        this.id = id;
        this.gmtModified = new Date();
    }

    public SingleLotteryAppSpecifyDto(boolean init4insert) {
        if (init4insert) {
            orderCount = 0;
            gmtCreate = new Date();
            gmtModified = gmtCreate;
        }
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getDuibaSingleLotteryId() {
        return duibaSingleLotteryId;
    }

    public void setDuibaSingleLotteryId(Long duibaSingleLotteryId) {
        this.duibaSingleLotteryId = duibaSingleLotteryId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getOrderCount() {
        return orderCount;
    }

    public void setOrderCount(Integer orderCount) {
        this.orderCount = orderCount;
    }

    public Integer getRemaining() {
        return remaining;
    }

    public void setRemaining(Integer remaining) {
        this.remaining = remaining;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-1.4.13-20170414.121004-1-sources.jar: cn/com/duiba/activity/center/api/dto/singlelottery/SingleLotteryAppSpecifyDto.java <==
package cn.com.duiba.activity.center.api.dto.singlelottery;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by yansen on 16/6/17.
 */
public class SingleLotteryAppSpecifyDto implements Serializable {
    private static final long serialVersionUID = 380776798442497916L;
    private Long id;

    private Long duibaSingleLotteryId; // 兑吧单品抽奖ID

    private Long appId; // appId

    private Integer orderCount; // 已兑数量

    private Integer remaining; // 剩余限额

    private Date gmtCreate;

    private Date gmtModified;

    @Override
    public String toString() {
        return "SingleLotteryAppSpecifyDO [id=" + id + "]";
    }

    /**
     * 
     * Creates a new instance of SingleLotteryAppSpecifyDto.
     *
     */
    public SingleLotteryAppSpecifyDto() {
        super();
    }

    /**
     * 
     * Creates a new instance of SingleLotteryAppSpecifyDto.
     *
     * @param id
     */
    public SingleLotteryAppSpecifyDto(Long id) {
        this.id = id;
        this.gmtModified = new Date();
    }

    /**
     * 
     * Creates a new instance of SingleLotteryAppSpecifyDto.
     *
     * @param init4insert
     */
    public SingleLotteryAppSpecifyDto(boolean init4insert) {
        if (init4insert) {
            orderCount = 0;
            gmtCreate = new Date();
            gmtModified = gmtCreate;
        }
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getDuibaSingleLotteryId() {
        return duibaSingleLotteryId;
    }

    public void setDuibaSingleLotteryId(Long duibaSingleLotteryId) {
        this.duibaSingleLotteryId = duibaSingleLotteryId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getOrderCount() {
        return orderCount;
    }

    public void setOrderCount(Integer orderCount) {
        this.orderCount = orderCount;
    }

    public Integer getRemaining() {
        return remaining;
    }

    public void setRemaining(Integer remaining) {
        this.remaining = remaining;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
